@@ -14,7 +14,7 @@ Usage::
     client: CostExplorerClient = boto3.client("ce")
     session_client: CostExplorerClient = session.client("ce")
 """
-from mypy_boto3_ce.client import CostExplorerClient as Client, CostExplorerClient
+from mypy_boto3_ce.client import CostExplorerClient, CostExplorerClient as Client
 
 
 __all__ = ("Client", "CostExplorerClient")
